===============================================
``psyclone.psyir.transformations.region_trans``
===============================================

.. automodule:: psyclone.psyir.transformations.region_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.transformations.region_trans
